@@ -2,7 +2,7 @@ from typing import Tuple
 
 import argparse
 
-from .xls_parser import XlsParserFormat
+from .xls_formats import XlsParserFormat
 
 
 def parse() -> Tuple[str, str, XlsParserFormat]:
